package de.fhdw.gaming.ipspiel23.ht.domain;

import java.util.Map;

import de.fhdw.gaming.core.domain.GameException;

/**
 * A builder for {@link HTPlayer}s.
 */
public interface IHTPlayerBuilder {
    
    /**
     * Changes the name of the player.
     * <p>
     * There is no default.
     *
     * @param newName The name of the player.
     * @return {@code this}
     */
    IHTPlayerBuilder changeName(String newName);

    /**
     * Changes the possible outcomes of the player.
     * <p>
     * There is no default.
     *
     * @param possibleOutcomes The possible outcomes of the player. The key for the first-level map is the answer of the
     *                         first player, the key for the second-level map is the answer of the second player.
     */
    IHTPlayerBuilder changePossibleOutcomes(Map<Answer, Map<Answer, Double>> possibleOutcomes);

    /**
     * Builds the player.
     *
     * @return The Heads or Tails player.
     * @throws GameException if creating the player is not allowed by the rules of the game.
     */
    IHTPlayer build() throws GameException;
}